==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/PropertyUpdatedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescription } from "./PropertyUpdatedEventArgsDescription";
/**
 * @hidden
 */
var PropertyUpdatedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyUpdatedEventArgsDescriptionMetadata, _super);
    function PropertyUpdatedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyUpdatedEventArgsDescriptionMetadata.b = function (a) {
        if (PropertyUpdatedEventArgsDescriptionMetadata.a == null) {
            PropertyUpdatedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyUpdatedEventArgsDescriptionMetadata.c(PropertyUpdatedEventArgsDescriptionMetadata.a);
        }
        if (a.j(PropertyUpdatedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(PropertyUpdatedEventArgsDescriptionMetadata.a);
    };
    PropertyUpdatedEventArgsDescriptionMetadata.c = function (a) {
        a.item("PropertyName", "String");
        a.item("OldValueRef", "(w:OldValue,wf:OldValue)DataRef");
        a.item("NewValueRef", "(w:NewValue,wf:NewValue)DataRef");
    };
    PropertyUpdatedEventArgsDescriptionMetadata.d = function (a) {
        PropertyUpdatedEventArgsDescriptionMetadata.b(a);
        a.aa("PropertyUpdatedEventArgs", function () { return new PropertyUpdatedEventArgsDescription(); });
        a.z("PropertyUpdatedEventArgs", PropertyUpdatedEventArgsDescriptionMetadata.a);
    };
    PropertyUpdatedEventArgsDescriptionMetadata.$t = markType(PropertyUpdatedEventArgsDescriptionMetadata, 'PropertyUpdatedEventArgsDescriptionMetadata');
    PropertyUpdatedEventArgsDescriptionMetadata.a = null;
    return PropertyUpdatedEventArgsDescriptionMetadata;
}(Base));
export { PropertyUpdatedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/PropertyUpdatedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescription } from "./PropertyUpdatedEventArgsDescription";
/**
 * @hidden
 */
var PropertyUpdatedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyUpdatedEventArgsDescriptionMetadata, _super);
    function PropertyUpdatedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyUpdatedEventArgsDescriptionMetadata.b = function (a) {
        if (PropertyUpdatedEventArgsDescriptionMetadata.a == null) {
            PropertyUpdatedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyUpdatedEventArgsDescriptionMetadata.c(PropertyUpdatedEventArgsDescriptionMetadata.a);
        }
        if (a.k(PropertyUpdatedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(PropertyUpdatedEventArgsDescriptionMetadata.a);
    };
    PropertyUpdatedEventArgsDescriptionMetadata.c = function (a) {
        a.item("PropertyName", "String");
        a.item("OldValueRef", "(w:OldValue,wf:OldValue)DataRef");
        a.item("NewValueRef", "(w:NewValue,wf:NewValue)DataRef");
    };
    PropertyUpdatedEventArgsDescriptionMetadata.d = function (a) {
        PropertyUpdatedEventArgsDescriptionMetadata.b(a);
        a.ac("PropertyUpdatedEventArgs", function () { return new PropertyUpdatedEventArgsDescription(); });
        a.ab("PropertyUpdatedEventArgs", PropertyUpdatedEventArgsDescriptionMetadata.a);
    };
    PropertyUpdatedEventArgsDescriptionMetadata.$t = markType(PropertyUpdatedEventArgsDescriptionMetadata, 'PropertyUpdatedEventArgsDescriptionMetadata');
    PropertyUpdatedEventArgsDescriptionMetadata.a = null;
    return PropertyUpdatedEventArgsDescriptionMetadata;
}(Base));
export { PropertyUpdatedEventArgsDescriptionMetadata };
